from ast import main
from flask import Flask, json, logging
from matplotlib.pylab import f
import streamlit as st
import logging

# Reset logging configuration to avoid conflicts from previous handlers
for handler in logging.root.handlers[:]:
    logging.root.removeHandler(handler)

# Flask app initialization (can be used for server-side integration)
app = Flask(__name__)

# ------------------------
# Define Streamlit Pages
# ------------------------

# Define the "About Me" page
about_page = st.Page(
    page="pages/about_me.py",  # Path to the Python file for this page
    title="About Me",  # Title displayed on the navigation
    default=True,  # Set as the default landing page
)

# Define the "Preprocessing" page
preprocessing_page = st.Page(
    page="pages/preprocessing.py",
    title="Preprocessing",  # Title for the preprocessing page
    icon=":material/bar_chart:",  # Icon displayed next to the page title
)

# Define the "Data Augmentation" page
augmentation_page = st.Page(
    page="pages/augmentation.py",
    title="Data Augmentation",  # Title for the augmentation page
    icon=":material/bar_chart:",
)

# Define the "Feature Engineering" page
feature_engineering_page = st.Page(
    page="pages/feature_engineering.py",
    title="Feature Engineering",  # Title for the feature engineering page
    icon=":material/bar_chart:",
)

# Define the "Data Metrics" page
data_metrics_page = st.Page(
    page="pages/data_metrics.py",
    title="Data Metrics",  # Title for the data metrics page
    icon=":material/bar_chart:",
)

# Define the "Algorithm Selection" page
algorithm_selection_page = st.Page(
    page="pages/algorithm_selection.py",
    title="Algorithm Selection",  # Title for selecting ML algorithms
    icon=":material/bar_chart:",
)

# Define the "Model Training" page
model_training_page = st.Page(
    page="pages/model_training.py",
    title="Model Training",  # Title for the model training page
    icon=":material/bar_chart:",
)

# Define the "Add and Apply Model" page
add_and_apply_model_page = st.Page(
    page="pages/add_and_apply_model.py",
    title="Model Training with Augmented Data",  # Title for combining and applying models
    icon=":material/bar_chart:",
)

# Define the "Model Application" page
model_application_page = st.Page(
    page="pages/model_application.py",
    title="Model Application",  # Title for using the trained model
    icon=":material/bar_chart:",
)

# Define the "Chat Bot" page
chatbot_page = st.Page(
    page="pages/chatbot.py",
    title="Chat Bot",  # Title for interacting with the chatbot
    icon=":material/bar_chart:",
)

# ------------------------
# Navigation Configuration
# ------------------------

# Organize pages into navigation groups
pg = st.navigation(
    {
        "Info": [about_page],  # "Info" category with the About Me page
        "Projects": [          # "Projects" category with ML pipeline pages
            preprocessing_page,
            augmentation_page,
            feature_engineering_page,
            data_metrics_page,
            algorithm_selection_page,
            model_training_page,
            add_and_apply_model_page,
            model_application_page,
            chatbot_page,
        ],
    }
)

# Add a simple title to the sidebar
st.sidebar.text("ALL ABOUT ")
st.sidebar.image("imgs/logo.png", width=400)  # Set desired width in pixels
st.sidebar.text("source : www.vecteezy.com/")

# Start running the navigation
pg.run()

# ------------------------
# Logging Configuration
# ------------------------

logger = logging.getLogger(__name__)  # Create a logger instance

# Define Rasa server endpoint (used if chatbot functionality is required)
URL = "http://localhost:5005/webhooks/rest/webhook"

# ------------------------
# Main Function
# ------------------------

def main():
    """
    Main function to display the sidebar instructions and guide users
    to navigate the app in the intended order.
    """

# Entry point for the application
if __name__ == "__main__":
    main()
