import streamlit as st

# Display the title and subtitle
st.title("🎥 Welcome to Netflix Content Analysis")
st.subheader("Unlock insights, explore trends, and dive deep into the world of Netflix content!")

# Add a stylish banner or header section
st.markdown(
    """
    <style>
    .banner {
        background: linear-gradient(to right, #ff7e5f, #feb47b);
        color: white;
        padding: 20px;
        border-radius: 10px;
        text-align: center;
        font-size: 20px;
        font-weight: bold;
        box-shadow: 0px 4px 6px rgba(0, 0, 0, 0.2);
    }
    </style>
    <div class="banner">
        📊 Your one-stop solution to analyze, preprocess, and model the Netflix dataset seamlessly!
    </div>
    """,
    unsafe_allow_html=True,
)

# Add an introduction with emojis for better engagement
st.markdown("## 📜 What this Offers?")
st.markdown(
    """
    - 🛠️ **Data Preprocessing**: Clean and handle missing values for a refined dataset.
    - 📈 **Augment Data**: Add realistic synthetic data to expand analysis.
    - 🔍 **Feature Engineering**: Extract impactful features for improved analysis.
    - 📊 **Visualizations & Metrics**: Generate insightful graphs and statistics.
    - 🤖 **Model Training**: Train ML models for meaningful predictions.
    - 🧮 **Custom Predictions**: Experiment with real-time scenarios and insights.
    """
)

# Add an interactive "Get Started" section with buttons or links to navigate
st.markdown("---")

st.markdown(
    """
    <style>
    .start {
        text-align: center;
        font-size: 25px;

    }
    </style>
    <div class="start">
        🚀 Get Started
    </div>
    """,
    unsafe_allow_html=True,
)

st.logo("imgs/logo2.png")

# Footer with styling
st.markdown("---")
st.markdown(
    """
    <style>
    .footer {
        text-align: center;
        font-size: 16px;
        color: gray;
        margin-top: 20px;
    }
    </style>
    <div class="footer">
        👨‍💻 Developed with 🧠 and 💻 by <b>Asif Khan</b> | 🌟 Empowering Netflix Data Analysis! 🌟
    </div>
    """,
    unsafe_allow_html=True,
)
